import random

from config import get_config
from command_system import as_plugin, RollbotResponse


def lift_simple_response(call, response):
    @as_plugin(call)
    def response_func(db, msg):
        return RollbotResponse(msg, txt=response)


def lift_echo_response(call, response):
    @as_plugin(call)
    def response_func(db, msg):
        return RollbotResponse(msg, txt=response.format(msg.raw_args or ""))


def lift_choice_response(call, options):
    @as_plugin(call)
    def response_func(db, msg):
        return RollbotResponse(msg, txt=random.choice(options))


dynamic = get_config("dynamic")

for cmd, response in dynamic["simple_responses"].items():
    lift_simple_response(cmd, response)

for cmd, response in dynamic["echo_responses"].items():
    lift_echo_response(cmd, response)

for cmd, options in dynamic["choice_responses"].items():
    opts = [y for x in ([o["value"]] * o.get("weight", 1) for o in options) for y in x]
    lift_choice_response(cmd, opts)
